@@ -224,6 +224,12 @@ impl Request {
         std::mem::take(&mut self.body)
     }
 
+    /// Consume this request and return its inner body.
+    #[inline]
+    pub fn into_body(self) -> Body {
+        self.body
+    }
+
     #[inline]
     pub(crate) fn state(&self) -> &RequestState {
         &self.state
@@ -283,7 +289,7 @@ impl RequestBuilder {
         let key = key.try_into();
         let value = value.try_into();
         if let (Ok(key), Ok(value)) = (key, value) {
-            self.headers.insert(key, value);
+            self.headers.append(key, value);
         }
         self
     }
